# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class DeployStreamHelmWaitingEvent(UniversalBaseModel):
    """
    Waiting for Helm deployment to complete (pods becoming ready).
    """

    message: typing.Optional[str] = pydantic.Field(default=None)
    """
    Optional status message
    """

    timestamp: str = pydantic.Field()
    """
    ISO 8601 timestamp
    """

    version_id: str = pydantic.Field()
    """
    Version ID being deployed
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
